#!/usr/bin/env node
const { repoName, runCommand, say } = require('./util.cjs');
const { getPackageJson, setPackageJson } = require('./package.cjs');

const cmd = {
	gitCheckout: `git clone --depth 1 https://github.com/OllieJT/create-svelte-trpc ${repoName}`,
	installDeps: `cd ${repoName} && yarn install`,
	cleanupBin: `rm -rf ${repoName}/bin`,
	cleanupGit: `rm -rf ${repoName}/.git`,
	initGit: `cd ${repoName}&& git init`
};

function initialize() {
	say(`🧑‍💻 CLONING: ${repoName}...`);

	const checkedOut = runCommand(cmd.gitCheckout);
	if (!checkedOut) process.exit(-1);

	say(`📦 Installing dependencies for ${repoName}...`);
	const installedDeps = runCommand(cmd.installDeps);
	if (!installedDeps) process.exit(-1);

	say(`📦 ...dependencies installed!`);
	say(`cd ${repoName} && yarn start`);
}

function cleanup() {
	runCommand(cmd.cleanupBin);
}

function updatePackageJson() {
	say(`🧑‍💻 Reading package.json...`);
	const pkg = getPackageJson();

	pkg.name = repoName || 'my-new-project';
	pkg.version = '0.0.1';
	delete pkg.repository;
	delete pkg.homepage;
	delete pkg.bin;

	setPackageJson(pkg);
	say(`🧑‍💻 ...updated package.json!`);
}

module.exports = { initialize, cleanup, updatePackageJson };
